function condhaz=hazard_cond(t,x,Y,X,d,h,kernel,type,typew)
% KERNEL ESTIMATION OF HAZARD FUNCTION
% inputs: t     ...time points in which we want calculate hazard, vector
%         x     ...vector of covariates we want to calculate hazard
%         Y     ...observed times, vector
%         X     ...vector of observed covariates
%         d     ...censoring indicator, vector, 0..censor, 1..event
%         h     ...vector of smoothing parameter h=c(ht,hx)
%           ht    ...smoothing parameter, number
%           hx    ...parametr for Nadaraya-Watson waights
%         kernel...one of: 'epan','gauss','quart','rect','trian'
%                  'epan'... default
%         type  ...type of estimate,
%                  possible: 'ex' ... exterior
%                            'in' ... interior, default
%         typew ...type of weights
% output: matrix of hazard values in times t and covariates x
%         j-th row of matrix is vector of hazard values in times t for j-th covariate in x
%         i-th column of matrix is vector of hazard values in i-th time in t for vector of covariate x
%         j-th row and i-th column .. i-th time, j-th covariate
%

hx=h(2);
ht=h(1);

tt=row(t);
xx=row(x);
Y=row(Y);
X=row(X);
d=row(d);
n=length(Y);
m=length(tt);


K=K_def(kernel);
W=W_def(K);



switch type
    case 'interior'
        [YY,in]=sort(Y);
        YY=row(YY);
        dd=row(d(in));
        XX=row(X(in));
        
        switch typew
            case 'nw'
                M=nwmatrix(XX,hx,xx,K);
            case 'll'
                M=llmatrix(XX,hx,xx,K);
                
        end
        
        
        
        %matice Y-tt
        Ymat=YY'*ones(1,m)-ones(n,1)*tt;
        
        
        MM=1-M*triu(ones(n,n),1);
        
        MM(MM==0)=0.00000001;
        W=M./MM;
        
        
        dmat=dd'*ones(1,m);
        s=(K_val(K,(Ymat)/ht)/ht).*dmat;
        
        % keyboard
        condhaz=W*s;
        
    case 'exterior'
        switch typew
            case 'nw'
                M=nwmatrix(X,hx,xx,K);
            case 'll'
                M=llmatrix(X,hx,xx,K);
                
        end
        %matice Y-tt
        Ymat=Y'*ones(1,m)-ones(n,1)*tt;
        %vypocet jmenovatele pro odstraneni nulovych hodnot
        t=(W_val(W,Ymat/ht));
        % keyboard
        Jm=M*t;
        Jm(Jm<=0.005)=0.005;
        
        dmat=d'*ones(1,m);
        s=(K_val(K,(-Ymat)/ht)/ht).*dmat;
        
        
        Ci=M*s;
        
        condhaz=Ci./Jm;
        
        
end

if strcmp(typew, 'll')
    condhaz(condhaz<0)=0;
end

end
