function [CV]=crossval_haz(h,Y,d,type,kernel,parallel)
%
% CROSSVALIDATION
% inputs: h       ...smoothing parameters, vector
%         Y       ...observed times, vector
%         d       ...censoring indicator, vector, 0..censor, 1..event
%         kernel  ...one of: 'epanechnikov','gaussian','rectangular','quartic'
%                    'epan'... default
%         type    ...type of estimate,
%                    possible: 'exterior' ... exterior
%                              'interior' ... interior, default
%         parallel...way of calculating
%                    FALSE ... common way
%                    TRUE  ... use more cores of computer
% output: vector of values of crossvalidation for smoothing parameters in h

if nargin == 3
    type = 'interior';
    kernel= 'epan';
    parallel=false;
elseif nargin == 4
    type = 'interior';
    parallel=false;
elseif nargin== 5
    parallel=false;
end

if  strcmp(type,'interior')
    type_s='empirical';
else
    type_s='kernsmooth';
end


I=find(isfinite(Y)&isfinite(d));
Y=Y(I);
d=d(I);


a=0;
n=length(Y);

nh=length(h);
CV=zeros(1,nh);

if  parallel
    parfor ii=1:nh
        hh=h(ii);
        b=max(Y)+hh;
        I1=Trapezoid('haz_sqr',a,b,1000,Y,d,hh,kernel,type);
        S=0;
        for i=1:n
            Yi=Y;
            di=d;
            Yi(i)=[];
            di(i)=[];
            S=S+hazard(Y(i),Yi,di,hh,kernel,type)*d(i)/surv(Y(i),Y,d,type_s,hh,kernel); 
        end
        
        cv1=I1-2*S/n;
        CV(ii)=cv1';
    end
    
    
else
    for ii=1:nh
        hh=h(ii);
        b=max(Y)+hh;
        I1=Trapezoid('haz_sqr',a,b,1000,Y,d,hh,kernel,type);
        S=0;
        for i=1:n
            Yi=Y;
            di=d;
            Yi(i)=[];
            di(i)=[];
            S=S+hazard(Y(i),Yi,di,hh,kernel,type)*d(i)/surv(Y(i),Y,d,type_s,hh,kernel);
            
        end
        
        cv1=I1-2*S/n;
        CV(ii)=cv1';
    end
    
end
end

