function [ML]=maxlike_haz(h,Y,d,type,kernel,parallel)
% MAXLIKE
% inputs: h       ...smoothing parameters, vector
%         Y       ...observed times, vector
%         d       ...censoring indicator, vector, 0..censor, 1..event
%         kernel  ...one of: 'epanechnikov','gaussian','rectangular','quartic'
%                    'epanechnikov'... default
%         type    ...type of estimate,
%                    possible: 'exterior' ... exterior
%                              'interior' ... interior, default
%         parallel...way of calculating
%                    FALSE ... common way
%                    TRUE  ... use more cores of computer, default
% output:  ML     ...vector of values of log likelihood for smoothing parameters in h
%
%

if nargin == 3
    type = 'interior';
    kernel= 'epan';
    parallel=false;
elseif nargin == 4
    type = 'interior';
    parallel=false;
elseif nargin== 5
    parallel=false;
end



I=find(isfinite(Y)&isfinite(d));
Y=Y(I);
d=d(I);

n=length(Y);

nh=length(h);
ML=zeros(1,nh);

if  parallel
    parfor ii=1:nh
        hh=h(ii);
        S=0;
        for i=1:n
            Yi=Y;
            di=d;
            Yi(i)=[];
            di(i)=[];
            S=S+log(hazard(Y(i),Yi,di,hh,kernel,type)^d(i)*exp(-Trapezoid('hazard',0,Y(i),500,Yi,di,hh,kernel,type)));
        end
        
        ML(ii)=S;
    end
else
    for ii=1:nh
        hh=h(ii);
        S=0;
        for i=1:n
            Yi=Y;
            di=d;
            Yi(i)=[];
            di(i)=[];
            S=S+log(hazard(Y(i),Yi,di,hh,kernel,type)^d(i)*exp(-Trapezoid('hazard',0,Y(i),500,Yi,di,hh,kernel,type)));
        end
        ML(ii)=S;
    end
    
end

ML(ML==-Inf)=-10^300;
end

