function S=surv(t,Y,d,type,h,kernel)
% KERNEL ESTIMATION OF SURVIVAL FUNCTION in times t
% inputs: t     ...time points in which we want calculate survival function, vector
%         Y     ...observed times, vector
%         d     ...censoring indicator, vector, 0..censor, 1..event
%         h     ...smoothing parameter, number, needed if type='kernsmooth'
%         kernel...one of: 'epan','gauss','quart','rect','trian'
%                  'epan'... default
%         type  ...type of estimate,
%                  possible: 'empirical'  ... empirical, default
%                            'kernsmooth' ... kernel
% output: vector of survival function values in times t
%%

if nargin == 2
    type = 'empirical';
elseif (nargin == 4 && type=='kernsmooth')|| nargin<2
    error('Malo vstupnich parametru')
elseif nargin== 5
    kernel= 'epan';
end
tt=row(t);

Y=row(Y);
n=length(Y);
p=length(t);

if strcmp(type,'empirical')
    I=Y'*ones(1,p)<=ones(n,1)*tt;
    
    S=1-sum(I)/(n+1);
    
elseif strcmp(type,'kernsmooth')
    K=K_def(kernel);
    W=W_def(K);
   
    %matice Y-tt
    Ymat=Y'*ones(1,p)-ones(n,1)*tt;
    
    t=(W_val(W,Ymat/h));
    % keyboard
    S=sum(t)/n;
    S(S<=0.005)=0.005;
    
end


end 

 
